@@ -191,7 +191,7 @@ class VariableClBuilderVideodrvSet(IsoTypeHelper, Variable):
 
     def set(self, value):
         if value == 'auto' or value is None:
-            self.value = "on" if self.Get('main.os_linux_system') == "desktop" else "off"
+            self.value = "on" if self.Get('os_builder_linux_system') == "desktop" else "off"
         else:
             self.value = value
         return self.value
